<?php

/*
Addon: Logo
*/

class VCLOGO_Logo {

	/*
	 * Contruct
	 */
    public function __construct() {

        add_action('wp_enqueue_scripts', array($this, 'load_scripts'));

        add_shortcode('vclogo_logo', array($this, 'shortcode_addon_func'));

        add_action('init', array($this, 'map_vc_addon'));

    }

    function load_scripts() {

		wp_enqueue_style( 'bootstrap' );
        wp_enqueue_style( 'vclogo-style' );
		wp_enqueue_style( 'font-awesome' );
		wp_enqueue_style( 'animations' );
		wp_enqueue_script( 'appear' );
		wp_enqueue_script( 'js-animations' );

    }
	
	/*
	 * Addon View
	 */
    public function shortcode_addon_func($atts, $content = null, $tag) {
		static $instance;
		$instance++;
		
        $date = '';

        extract(shortcode_atts(array(

            'logo_image' 	=> '',
			'logo_size'		=> 'full',
			'logo_align'	=> 'center',
			'logo_link'		=> 'on',
			'logo_url'		=> home_url( '/' ),
			'logo_target'	=> '_self',
			'addon_animate'	=> 'off',
			'effect'		=> 'fade-in',
			'delay'			=> '0',
			

        ), $atts));
		
		$logo_url_array = wp_get_attachment_image_src( $logo_image, $logo_size );
        
		$output = '<div class="vclogo vclogo-logo vclogo-align-'.esc_html($logo_align).' vclogo-logo-'.esc_html($instance).vclogo_animate_class($addon_animate,$effect,$delay).'>';
			
			if($logo_link == 'on') : $output .= '<a href="'.esc_url($logo_url).'" target="'.esc_html($logo_target).'">'; endif;
				$output .= '<img src="'.esc_url($logo_url_array[0]).'" alt="'.esc_html__('Logo','vclogo').'">';
			if($logo_link == 'on') : $output .= '</a>'; endif;
			
			
        $output .= '</div>';

        return $output;
    }	

	
	/*
	 * Addon Backend
	 */	
    function map_vc_addon() {
        if (function_exists("vc_map")) {

            vc_map(array(
                "name" => esc_html__("Logo", "vclogo"),
                "base" => "vclogo_logo",
                "content_element" => true,
                "show_settings_on_create" => true,
                "category" => esc_html__("VC Logo", "vclogo"),
                'description' => esc_html__('Add your Logo addon', 'vclogo'),
                "icon" => VCLOGO_URL . '/assets/img/vc-logo.png',
                "params" => array(
					array(
						"type" => "attach_image",
						"class" => "",
						"heading" => esc_html__("Upload your Logo", 'vclogo'),
						"param_name" => "logo_image",
					),
					array(
						"type" => "dropdown",
						"class" => "",
						"heading" => esc_html__("Size", 'vclogo'),
						"param_name" => "logo_size",
						"value" => array(
									esc_html__('Original Size','vclogo') => 'full',
									esc_html__('Thumbnail','vclogo') 	=> 'thumbnail',
									esc_html__('Medium','vclogo') 		=> 'large',
									esc_html__('Large','vclogo')  		=> 'large'																		
						),
					),					
					
					// TARGET
					array(
					    "type" => "dropdown",
						"class" => "",
						"heading" => esc_html__("Align", 'vclogo'),
						"param_name" => "logo_align",
						"value" => array(
									esc_html__('Center','vclogo')  => 'center',
									esc_html__('Left','vclogo') 	  => 'left',
									esc_html__('Right','vclogo')   => 'right',									
						),
					),			  
									
					array(
					    "type" => "dropdown",
						"class" => "",
						"heading" => esc_html__("Link", 'vclogo'),
						"param_name" => "logo_link",
						"value" => array(
									esc_html__('On','vclogo') 	=> 'on',
									esc_html__('Off','vclogo') 	=> 'off'
						),
						"group" => "Target"
					),
									
					array(
						"type" => "textfield",
						"class" => "",
						"heading" => esc_html__("Url",'vclogo'),
						"param_name" => "logo_url",
						"description" => esc_html__('Leave empty for homelink','vclogo'),					  
						'dependency' => array(
								'element' => 'logo_link',
								'value' => array( 'on' )
						),
						"group" => "Target"
					),
									
					array(
						"type" => "dropdown",
						"class" => "",
						"heading" => esc_html__("Target", 'vclogo'),
						"param_name" => "logo_target",
						"value" => array(
									esc_html__('Self (Same Window)','vclogo') => '_self',
									esc_html__('Blank (New Window)','vclogo') => '_blank'
									
						),
						'dependency' => array(
								'element' => 'logo_link',
								'value' => array( 'on' )
						),
						"group" => "Target"
					),
					
					// ANIMATION								  							  		  
					array(
						"type" => "dropdown",
						"class" => "",
						"heading" => esc_html__("Animate", 'vclogo'),
						"param_name" => "addon_animate",
						"value" => array(
										esc_html__('Off','vclogo') 	=> 'off',
										esc_html__('On','vclogo') 	=> 'on'
										
						),
						"group" => "Animation"
					),			  
					array(
						"type" => "dropdown",
						"class" => "",
						"heading" => esc_html__("Animate Effects", 'vclogo'),
						"param_name" => "effect",
						"value" => vclogo_animation_effect(),
						"dependency" => array(
							"element" => "addon_animate",
							"value" => array( "on" )
						),
						"group" => "Animation"				   
					),				  
					array(
						"type" => "textfield",
						"class" => "",
						"heading" => esc_html__("Animate Delay (ms)",'vclogo'),
						"param_name" => "delay",
						"description" => "ex 1000",					  
						"dependency" => array(
							"element" => "addon_animate",
							"value" => array( "on" )
						),
						"value" => "0",
						"group" => "Animation"					  
					),
                ),
            ));


        }
    }

} // End Class

if (class_exists('WPBakeryShortCode')) {
    class WPBakeryShortCode_VCLOGO_Logo extends WPBakeryShortCode {
    }
}

// Initialize Element Class
if (class_exists('VCLOGO_Logo')) {
    new VCLOGO_Logo();
}

